@@ -23,6 +23,7 @@ from mypy_boto3_secretsmanager.type_defs import (
     DeleteResourcePolicyResponseTypeDef,
     DeleteSecretResponseTypeDef,
     DescribeSecretResponseTypeDef,
+    FilterTypeDef,
     GetRandomPasswordResponseTypeDef,
     GetResourcePolicyResponseTypeDef,
     GetSecretValueResponseTypeDef,
@@ -36,6 +37,7 @@ from mypy_boto3_secretsmanager.type_defs import (
     TagTypeDef,
     UpdateSecretResponseTypeDef,
     UpdateSecretVersionStageResponseTypeDef,
+    ValidateResourcePolicyResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -58,25 +60,26 @@ class Exceptions:
     LimitExceededException: Type[Boto3ClientError]
     MalformedPolicyDocumentException: Type[Boto3ClientError]
     PreconditionNotMetException: Type[Boto3ClientError]
+    PublicPolicyException: Type[Boto3ClientError]
     ResourceExistsException: Type[Boto3ClientError]
     ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class SecretsManagerClient:
     """
-    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client)
+    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         """
 
     def cancel_rotate_secret(self, SecretId: str) -> CancelRotateSecretResponseTypeDef:
         """
-        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         """
 
     def create_secret(
@@ -90,12 +93,12 @@ class SecretsManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateSecretResponseTypeDef:
         """
-        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         """
 
     def delete_resource_policy(self, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         """
 
     def delete_secret(
@@ -105,12 +108,12 @@ class SecretsManagerClient:
         ForceDeleteWithoutRecovery: bool = None,
     ) -> DeleteSecretResponseTypeDef:
         """
-        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         """
 
     def describe_secret(self, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
-        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         """
 
     def generate_presigned_url(
@@ -121,7 +124,7 @@ class SecretsManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         """
 
     def get_random_password(
@@ -136,19 +139,19 @@ class SecretsManagerClient:
         RequireEachIncludedType: bool = None,
     ) -> GetRandomPasswordResponseTypeDef:
         """
-        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         """
 
     def get_resource_policy(self, SecretId: str) -> GetResourcePolicyResponseTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         """
 
     def get_secret_value(
         self, SecretId: str, VersionId: str = None, VersionStage: str = None
     ) -> GetSecretValueResponseTypeDef:
         """
-        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         """
 
     def list_secret_version_ids(
@@ -159,21 +162,25 @@ class SecretsManagerClient:
         IncludeDeprecated: bool = None,
     ) -> ListSecretVersionIdsResponseTypeDef:
         """
-        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         """
 
     def list_secrets(
-        self, MaxResults: int = None, NextToken: str = None
+        self,
+        MaxResults: int = None,
+        NextToken: str = None,
+        Filters: List[FilterTypeDef] = None,
+        SortOrder: Literal["asc", "desc"] = None,
     ) -> ListSecretsResponseTypeDef:
         """
-        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         """
 
     def put_resource_policy(
-        self, SecretId: str, ResourcePolicy: str
+        self, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = None
     ) -> PutResourcePolicyResponseTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         """
 
     def put_secret_value(
@@ -185,12 +192,12 @@ class SecretsManagerClient:
         VersionStages: List[str] = None,
     ) -> PutSecretValueResponseTypeDef:
         """
-        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         """
 
     def restore_secret(self, SecretId: str) -> RestoreSecretResponseTypeDef:
         """
-        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         """
 
     def rotate_secret(
@@ -201,17 +208,17 @@ class SecretsManagerClient:
         RotationRules: "RotationRulesTypeTypeDef" = None,
     ) -> RotateSecretResponseTypeDef:
         """
-        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         """
 
     def tag_resource(self, SecretId: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         """
 
     def untag_resource(self, SecretId: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         """
 
     def update_secret(
@@ -224,7 +231,7 @@ class SecretsManagerClient:
         SecretString: str = None,
     ) -> UpdateSecretResponseTypeDef:
         """
-        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         """
 
     def update_secret_version_stage(
@@ -235,10 +242,17 @@ class SecretsManagerClient:
         MoveToVersionId: str = None,
     ) -> UpdateSecretVersionStageResponseTypeDef:
         """
-        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        """
+
+    def validate_resource_policy(
+        self, ResourcePolicy: str, SecretId: str = None
+    ) -> ValidateResourcePolicyResponseTypeDef:
+        """
+        [Client.validate_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.18/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         """
